Contains the entry point for your application.
Contains the entry point for your application.
(main {:keys [start-fn stop-fn stream-routes batch-routes actor-routes modes]})(main start-fn stop-fn stream-routes)(main start-fn stop-fn stream-routes actor-routes)The entry point for your application.
Accepts stream-routes as a nested map keyed by the topic entities. Each topic entity is a map with a handler-fn described. For eg.,
{:default {:handler-fn (fn [message] :success)}} :handler-fn must return :success, :retry or :skip
start-fn takes no parameters, and will be run on application startup. stop-fn takes no parameters, and will be run on application shutdown.
The entry point for your application.
Accepts stream-routes as a nested map keyed by the topic entities.
Each topic entity is a map with a handler-fn described. For eg.,
{:default {:handler-fn (fn [message] :success)}}
:handler-fn must return :success, :retry or :skip
start-fn takes no parameters, and will be run on application startup.
stop-fn takes no parameters, and will be run on application shutdown.(start actor-start-fn stream-routes batch-routes actor-routes modes)Starts up Ziggurat's config, reporters, actor fn, rabbitmq connection and then streams, server etc
Starts up Ziggurat's config, reporters, actor fn, rabbitmq connection and then streams, server etc
(stop actor-stop-fn _modes)Stops all of Ziggurat's application states in dependency order and then calls actor-stop-fn. The modes the application was started with do not affect the stop order; states belonging to modes that were never started stop as no-ops.
Stops all of Ziggurat's application states in dependency order and then calls actor-stop-fn. The modes the application was started with do not affect the stop order; states belonging to modes that were never started stop as no-ops.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |